%?mingw_package_header

Name:           mingw-cairo
Version:        1.14.6
Release:        %mkrel 1
Summary:        MinGW Windows Cairo library

License:        LGPLv2 or MPLv1.1
URL:            http://cairographics.org
Source0:        http://cairographics.org/releases/cairo-%{version}.tar.xz
Group:          Development/Other

# Backported upstream patches to add API required by gtk3
Patch0:         0001-win32-Add-cairo-API-to-set-up-a-Win32-surface-for-an.patch
Patch10:         build-fix.patch
 
BuildArch:      noarch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-fontconfig
BuildRequires:  mingw32-freetype
BuildRequires:  mingw32-libxml2
BuildRequires:  mingw32-pixman
BuildRequires:  mingw32-libpng
BuildRequires:  mingw32-win-iconv
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-glib2

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-fontconfig
BuildRequires:  mingw64-freetype
BuildRequires:  mingw64-libxml2
BuildRequires:  mingw64-pixman
BuildRequires:  mingw64-libpng
BuildRequires:  mingw64-win-iconv
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-glib2

BuildRequires:  mingw-w64-tools
BuildRequires:  pkgconfig

%description
MinGW Windows Cairo library.


# Win32
%package -n mingw32-cairo
Summary:        MinGW Windows Cairo library
Requires:       mingw32-fontconfig
Requires:       mingw32-freetype
Requires:       pkgconfig

%description -n mingw32-cairo
MinGW Windows Cairo library.

%package -n mingw32-cairo-static
Summary:        Static version of the MinGW Windows Cairo library
Requires:       mingw32-cairo = %{version}-%{release}
Group:          Development/Other

%description -n mingw32-cairo-static
Static version of the MinGW Windows Cairo library.

# Win64
%package -n mingw64-cairo
Summary:        MinGW Windows Cairo library
Requires:       mingw64-fontconfig
Requires:       mingw64-freetype
Requires:       pkgconfig

%description -n mingw64-cairo
MinGW Windows Cairo library.

%package -n mingw64-cairo-static
Summary:        Static version of the MinGW Windows Cairo library
Requires:       mingw64-cairo = %{version}-%{release}
Group:          Development/Other

%description -n mingw64-cairo-static
Static version of the MinGW Windows Cairo library.


%?mingw_debug_package


%prep
%setup -q -n cairo-%{version}
%autopatch -p1


%build
# Function to generate an import library for delay-loading
gen_delay_lib()
{
    local DLL="$1"
    local OUT_IMPLIB="$2"

    gendef - "%{mingw32_bindir}/$DLL" > build_win32/delay_load.def
    %{mingw32_dlltool} --def build_win32/delay_load.def --kill-at --output-delaylib "build_win32/$OUT_IMPLIB"

    gendef - "%{mingw64_bindir}/$DLL" > build_win64/delay_load.def
    %{mingw64_dlltool} --def build_win64/delay_load.def --kill-at --output-delaylib "build_win64/$OUT_IMPLIB"
}

mkdir build_win32
mkdir build_win64

# Generate import libs for delay-loading fontconfig and freetype
gen_delay_lib libfontconfig-1.dll libfontconfig-delayed.dll.a
gen_delay_lib libfreetype-6.dll libfreetype-delayed.dll.a

MINGW_CONFIGURE_ARGS=" \
  ax_cv_c_float_words_bigendian=no \
  --disable-pthread \
  --disable-xlib \
  --disable-xcb \
  --enable-win32 \
  --enable-fc \
  --enable-ft \
  --enable-png \
  --enable-static \
  --enable-gobject \
  --enable-tee"

# The regular %%mingw_configure macro can't be used here as we need to inject custom
# environment variables which are different between the win32 and win64 build
pushd build_win32
    %mingw32_configure \
        FONTCONFIG_LIBS="-L`pwd` -lfontconfig-delayed" \
        FREETYPE_LIBS="-L`pwd` -lfreetype-delayed"
popd

pushd build_win64
    %mingw64_configure \
        FONTCONFIG_LIBS="-L`pwd` -lfontconfig-delayed" \
        FREETYPE_LIBS="-L`pwd` -lfreetype-delayed"
popd

%mingw_make %{?_smp_mflags} V=1


%install
%mingw_make install DESTDIR=$RPM_BUILD_ROOT

rm -f $RPM_BUILD_ROOT%{mingw32_libdir}/charset.alias
rm -f $RPM_BUILD_ROOT%{mingw64_libdir}/charset.alias

rm -r $RPM_BUILD_ROOT%{mingw32_datadir}/gtk-doc
rm -r $RPM_BUILD_ROOT%{mingw64_datadir}/gtk-doc

# Drop all .la files
find $RPM_BUILD_ROOT -name "*.la" -delete


# Win32
%files -n mingw32-cairo
%license COPYING COPYING-LGPL-2.1 COPYING-MPL-1.1
%{mingw32_bindir}/libcairo-2.dll
%{mingw32_bindir}/libcairo-gobject-2.dll
%{mingw32_bindir}/libcairo-script-interpreter-2.dll
%{mingw32_includedir}/cairo/
%{mingw32_libdir}/libcairo.dll.a
%{mingw32_libdir}/libcairo-gobject.dll.a
%{mingw32_libdir}/libcairo-script-interpreter.dll.a
%{mingw32_libdir}/pkgconfig/cairo-fc.pc
%{mingw32_libdir}/pkgconfig/cairo-ft.pc
%{mingw32_libdir}/pkgconfig/cairo-gobject.pc
%{mingw32_libdir}/pkgconfig/cairo-pdf.pc
%{mingw32_libdir}/pkgconfig/cairo-png.pc
%{mingw32_libdir}/pkgconfig/cairo-ps.pc
%{mingw32_libdir}/pkgconfig/cairo-script.pc
%{mingw32_libdir}/pkgconfig/cairo-svg.pc
%{mingw32_libdir}/pkgconfig/cairo-tee.pc
%{mingw32_libdir}/pkgconfig/cairo-win32-font.pc
%{mingw32_libdir}/pkgconfig/cairo-win32.pc
%{mingw32_libdir}/pkgconfig/cairo.pc

%files -n mingw32-cairo-static
%{mingw32_libdir}/libcairo.a
%{mingw32_libdir}/libcairo-gobject.a
%{mingw32_libdir}/libcairo-script-interpreter.a

# Win64
%files -n mingw64-cairo
%license COPYING COPYING-LGPL-2.1 COPYING-MPL-1.1
%{mingw64_bindir}/libcairo-2.dll
%{mingw64_bindir}/libcairo-gobject-2.dll
%{mingw64_bindir}/libcairo-script-interpreter-2.dll
%{mingw64_includedir}/cairo/
%{mingw64_libdir}/libcairo.dll.a
%{mingw64_libdir}/libcairo-gobject.dll.a
%{mingw64_libdir}/libcairo-script-interpreter.dll.a
%{mingw64_libdir}/pkgconfig/cairo-fc.pc
%{mingw64_libdir}/pkgconfig/cairo-ft.pc
%{mingw64_libdir}/pkgconfig/cairo-gobject.pc
%{mingw64_libdir}/pkgconfig/cairo-pdf.pc
%{mingw64_libdir}/pkgconfig/cairo-png.pc
%{mingw64_libdir}/pkgconfig/cairo-ps.pc
%{mingw64_libdir}/pkgconfig/cairo-script.pc
%{mingw64_libdir}/pkgconfig/cairo-svg.pc
%{mingw64_libdir}/pkgconfig/cairo-tee.pc
%{mingw64_libdir}/pkgconfig/cairo-win32-font.pc
%{mingw64_libdir}/pkgconfig/cairo-win32.pc
%{mingw64_libdir}/pkgconfig/cairo.pc

%files -n mingw64-cairo-static
%{mingw64_libdir}/libcairo.a
%{mingw64_libdir}/libcairo-gobject.a
%{mingw64_libdir}/libcairo-script-interpreter.a




%changelog
* Wed Apr 06 2016 tv <tv> 1.14.6-1.mga6
+ Revision: 998859
- patch 10: fix build
- reeanble patch
- try disable patch
- new release
- sync with FC
- new release

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.12.16-3.mga5
+ Revision: 749630
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.12.16-2.mga5
+ Revision: 682411
- Mageia 5 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 1.12.16-1.mga4
+ Revision: 483452
- imported package mingw-cairo

